#
# spec file for package k9s
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           k9s
Version:        0.50.5
Release:        1.1
Summary:        Curses based terminal UI for Kubernetes clusters
License:        Apache-2.0
URL:            https://github.com/derailed/k9s
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.24
ExcludeArch:    %{ix86}

%description
K9s provides a curses based terminal UI to interact with your Kubernetes
clusters. The aim of this project is to make it easier to navigate, observe
and manage your applications in the wild. K9s continually watches Kubernetes
for changes and offers subsequent commands to interact with observed
Kubernetes resources.

%prep
%setup -qa1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

%ifarch i586 s390x armv7hl armv7l armv7l:armv6l:armv5tel armv6hl riscv64
export CGO_ENABLED=1
%else
export CGO_ENABLED=0
%endif
make GO_FLAGS="-mod=vendor -buildmode=pie" GIT_REV="${COMMIT_HASH:0:8}" VERSION="%{version}" DATE="${BUILD_DATE}" build

%install
# Install the binary.
mkdir -p %{buildroot}%{_bindir}/
install -m 0755 execs/k9s %{buildroot}%{_bindir}/k9s

%files
%license LICENSE
%doc README.md
%{_bindir}/k9s

%changelog
* Thu May  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.5:
  * Resolved Issues
  - Pod overview shows wrong number of running containers with
    sidecar init-container
  - [0.50.4] k9s crashes when attempting to load logs
  - Port Forward deleted without UI notification when forwarding
    to wrong port
  - [0.50.4] k9s crashes when filtering based on labels
  - k9s doesn't honor the --namespace parameter
  * Dependencies
  - chore(deps): bump github.com/anchore/grype from 0.91.0 to
    0.91.2 (#3315)
  - chore(deps): bump github.com/anchore/syft from 1.22.0 to
    1.23.1 (#3316)
  - chore(deps): bump k8s.io/apimachinery from 0.32.3 to 0.33.0
    (#3317)
* Sun Apr 20 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.4:
  * Rel v0.50.4 (#3293)
  * Feature/default_view (#2866)
  * fix: set default request timeout to 120 seconds (#3253)
  * feat: add hostPathVolume (docker) (#3277)
  * fix: respect insecure flag when switch context (#3292)
  * plugins: add a plugin to start an alpine:latest container in
    current context/namespace (#3265)
  * Add plugin to temporarily scale down/up all deployments,
    statefulsets, and daemonsets in a namespace using szero (#3259)
  * update slack invite link
* Mon Apr 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.3:
  * Maintenance Release!
    A bit more code spring cleaning/TLC and address a few bugs:
  - [RBAC View] Fix issue bombing out on RBAC cluster roles
  - [Custom Views] Fix issue with parsing jq filters and bombing
    out (Big Thanks to Pierre for flagging it!)
* Fri Apr 11 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.2:
  * 5-0, 5-0 HotFix!
    It looks like we've broken a few (more) things in the clean up
    process
    This is what you get for trying to refresh a ~10 year old code
    base
    Apologizes for the disruption in the farce. Hopefully much
    happier on v0.50.2...
    Are we there yet? Crossing fingers AND toes...
  * Resolved Issues
  - #3267 Show some output or message when no resources are found
  - #3266 Command alias :dp fails with "no resource meta defined
    for deployments" error
  - #3264 can't execute get(y) or describe(d) in StorageClass
    view
  - #3260 yaml view of pod will crash the app (Boom!! cannot deep
    copy int. (Maybe??)
  * Dependencies
  - chore(deps): bump github.com/fsnotify/fsnotify from 1.8.0 to
    1.9.0 (#3249)
  - chore(deps): bump github.com/anchore/syft from 1.21.0 to
    1.22.0 (#3250)
  - chore(deps): bump golang from 1.24.1-alpine3.21 to
    1.24.2-alpine3.21 (#3251)
  - chore(deps): bump golang.org/x/text from 0.23.0 to 0.24.0
    (#3252)
* Thu Apr 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.1:
  * 5-0, 5-0 HotFix!
    It looks like we've broken a few things in the clean up process
    Apologizes for the disruption in the farce. Hopefully happier
    on v0.50.1...
    Crossing fingers and toes!
  * Resolved Issues
  - #3262 Crash when no shellPod is defined in config file
  - #3261 aliases with namespace and/or labels produce an error
  - #3258 mac silicon 0.50.0 runtime error
  - #3257 pods are reported to run on nodes they are not running
    on
  - #3256 Pods view seems broken in 0.50.0
  - #3255 Custom view does not work randomly
* Wed Apr  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.50.0:
  * 5-O, 5-0... Spring Cleaning In Effect!
    Careful on this upgrade!
    We've gone thru lots of code revamp/refactor on this drop, so
    mileage may vary!!
  * K9s Slow?
    It looks like K9s performance took a dive in the wrong
    direction circa v0.40.x releases.
    Took a big perf/cleanup pass to improve perf and think this
    release should help a lot (famous last words...)
    NOTE! As my dear granny use to say: You can't cook a great
    meal without trashing the kitchen,
    So likely I have broken a few things in the process. So thread
    carefully and report back!
  * Now with Super Column Blow!
    By general demand, juice up custom views! In a feature we like
    to refer to as Super Column Blow...
    As of this drop, you can go full Chuck Norris and sprinkle some
    of your JQ_FU with you custom views.
  * Resolved Issues
  - #3226 Filter view will show mess when filtering some string
  - #3224 Respect kubectl.kubernetes.io/default-container
    annotation
  - #3222 Option to Display Resource Names Without API Version
    Prefix
  - #3210 Description line is buggy
  * Dependencies
  - chore(deps): bump actions/setup-go from 5.3.0 to 5.4.0
    (#3234)
  - chore(deps): bump helm.sh/helm/v3 from 3.17.1 to 3.17.2
    (#3235)
  - chore(deps): bump k8s.io/apiextensions-apiserver from 0.32.2
    to 0.32.3 (#3213)
  - chore(deps): bump golangci/golangci-lint-action from 6.5.1 to
    6.5.2 (#3215)
  - chore(deps): bump k8s.io/kubectl from 0.32.2 to 0.32.3
    (#3214)
  - chore(deps): bump github.com/containerd/containerd from
    1.7.24 to 1.7.27 (#3216)
* Sun Mar 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.10:
  * Rel v0.40.10 (#3206)
  * update docs
  * chore(deps): bump golang.org/x/net from 0.35.0 to 0.36.0
    (#3200)
* Sun Mar 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.9:
  * Rel v0.40.9 (#3205)
  * Extend the argocd plugin by refresh and en/dis-abling of app
    sync (#3142)
  * chore(deps): bump golangci/golangci-lint-action from 6.3.2 to
    6.5.0 (#3127)
  * fix(coloring): invalid color application for rows with VALID
    column (#3137)
* Wed Mar 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.8:
  * Resolved Issues
  - #3193 Feature Request: View aliases with custom columns
  - #3192 Allow readonly indicator respect the noIcons
    configuration
  - #3153 Add support for bunyan logging
  * Contributed PRs
    Please be sure to give Big Thanks! and ATTA Girls/Boys! to all
    the fine contributors for making K9s better for all of us!!
  - #3186 fix: allow absolute paths for the 'dir' command
  - #3152 Feat: Add plugin support for parsing logs with bunyan
    cli #3153
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.7:
  * Rel v0.40.7 (#3188)
  * fix: allow absolute paths for the 'dir' command (#3186)
  * feat: add plugin to run `vector top` in vector.dev container,
    hotkey `h` (#3170)
* Mon Mar 10 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.6:
  * Breaking change
    Moved portForwardAddress out of
    clusterXXX/contextYYY/config.yaml and into the main K9s config
    file.
    This is a global preference based on your setup vs a
    cluster/context specific attribute.
    K9s will nag you in the logs if a specific context config still
    contains this attribute but should not prevent the
    configuration load.
  * Column Blow Reloaded!
    We've added another property to the custom view. You can now
    also specify namespace specific column definition for a given
    resource.  For instance, view pods in any namespace using one
    configuration and view pods in fred namespace using an
    alternate configuration.
    (See the example in the release
    https://github.com/derailed/k9s/releases/tag/v0.40.6)
    Additionally, we've added a new column attribute aka Show -> S.
    This allows you to now override the default resource column
    wide attribute when set.
  * Resolved Issues
  - #3179 Resource name with full api or group displayed
    (somewhere and sometimes)
  - #3178 Cronjobs with the same name in different namespaces
    appear together
  - #3176 Trigger all marked cronjobs
  - #3162 Context configs: context directory created under wrong
    cluster after context switch
  - #3161 Force wide-only columns to appear outside of wide view
  - #3147 Prompt style is overriden by body
  - #3139 CPU/R:L and MEM/R:L columns invalid in views.yaml
  - #3138 Subresources are not shown correctly in the RBAC view
  * Contributed PRs
  - Please be sure to give Big Thanks! and ATTA Girls/Boys! to
    all the fine contributors for making K9s better for all of
    us!!
  - #3182 fix: Use the latest version when downloading the Ubuntu
    deb file
  - #3168 fix(history): handle cases where special commands add
    their command their command to the history
  - #3159 Added hard contrast gruvbox skins
  - #3149 fix: Pass grv on gotoResource as a String to fix
    non-default apiGroup list
  - #3149 Add externalsecrets plugin
  - #3140 fix: Avoid false positive matches in enableRegion
    (#3093)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.5:
  * Rel 0.40.5 (#3136)
  * chore(deps): bump k8s.io/apiextensions-apiserver from 0.32.1 to
    0.32.2 (#3126)
* Tue Feb 18 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.4:
  * Resolved Issues
  - #3122 Viewing events is no longer sorted by LAST SEEN
  - #3120 Custom View Column Mismatch in K9s: Shuffled Values in
    Pods View
  - #3119 Custom Views Fail to Load with %% in Column Names
  - #3118 selecting an alias, the wrong resources are being shown
* Mon Feb 17 2025 Andreas Schwab <schwab@suse.de>
- Enable cgo on riscv64
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.3:
  * Resolved Issues
  - #3116 Cannot list custom CRD's since v0.40.1 (with feelings!)
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.2:
  * Resolved Issues
  - #3116 Cannot list custom CRD's since v0.40.1
* Mon Feb 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.1:
  * Resolved Issues
  - #3113 0.40.0 can't retain temporary view sort
  - #3111 k9s can't describe or print YAML for HPAs in all
    namespaces view
  - #2966 Go to the Contexts page and filter, contexts that are
    matched will be filtered ou
  - #2962 Small colour/filtering related bug
  - #2961 Drain node with the -disable-eviction
  - #2958 Restart count in container view associated with the
    wrong container
  - #2945 Could we add ServiceAccount Column in v1/POD view
* Sun Feb 16 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- fix builds on s390x
- properly set the build date
* Sun Feb 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.40.0 (no releases between 0.32.7 and this
  one):
  We are pretty stocked about this drop (hopefully...) as we've
  fully enabled custom columns support in K9s!
  Historically, one could customize the view for a given resource
  by adding a definition in views.yaml.
  From there one could change sort order and re-arrange the
  standard column layout.
  Several folks voiced the need to add a column for a given
  label/annotation or any other fields available on a resource.  To
  date, this wasn't possible
  So... without further ado, let see what we can now do with Custom
  Views ding dang deal!
  It all starts with a few new directives available in views.yaml
  More information on Custom Views and columns are in the release
  notes:
  https://github.com/derailed/k9s/releases/tag/v0.40.0
  * Resolved Issues
  - #3064 Question: brew formula k9s vs derailed/k9s/k9s
  - #3061 k9s not opening active namespace or namespace specified
    via -n
  - #3044 CRDs are loaded incorrectly into metadata registry,
    cause sporadic "Jump Owner" issues
  - #2995 Latest image on quay.io contains "failed" kubectl
    binary
* Tue Nov 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.7:
  * Rel v0.32.7 (#2971)
  * Put log levels in order in cmd help (#2960)
  * Update go version to 1.23.X in README (#2968)
  * feat(dao,used-by-cmd): check imagePullSecrets as well (#2964)
  * Feature: add pod last restart column to pod section (#2946)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.6:
  * Release v0.32.6 (#2955)
  * Fix "Mark Range": reduce maximum namespaces in `favorites`, fix
    shadowing of ctrl+space (#2927)
  * feat: add irregular pod terminations to Faults view (#2738)
    (#2935)
  * chore(deps): bump k8s.io/metrics from 0.31.0 to 0.31.2 (#2941)
  * Adding Argo Rollouts plugin version for PowerShell (#2937)
  * Adding eks-node-viewer plugin (#2914)
  * chore(plugins,remove-finalizers): make sure the resources api
    group is respected (#2926)
  * Bump helm.sh/helm/v3 from 3.14.4 to 3.16.2 (#2915)
  * chore(deps): bump actions/setup-go from 5.0.2 to 5.1.0 (#2939)
  * chore(deps): bump actions/checkout from 4.2.1 to 4.2.2 (#2940)
  * fixed conflicting plugin shortcuts, and added 2 new plugins
    (#2930)
  * fix: add kubeconfig if k9s is launched with --kubeconfig
    (#2932)
  * chore: build-status tag url (#2933)
  * feat: added StartupProbes status (S) to the PROBES column in
    the container render (#2920)
  * feat(2896): Add toggle keda plugin (#2897)
  * Add argocd plugin (#2898)
  * Include sidecar containers requests and limits (#2848)
  * Bump actions/checkout from 4.1.6 to 4.2.1 (#2906)
  * Bump golangci/golangci-lint-action from 6.1.0 to 6.1.1 (#2905)
  * Update README.md (#2890)
  * chore: fix function name (#2861)
  * Bump k8s.io/apiextensions-apiserver from 0.30.1 to 0.31.1
    (#2887)
  * Bump github.com/rs/zerolog from 1.32.0 to 1.33.0 (#2868)
  * Bump github.com/fatih/color from 1.16.0 to 1.17.0 (#2869)
  * Bump alpine from 3.20.2 to 3.20.3 (#2876)
  * Fix Mark-Range command: ensure that NS Favorite doesn't exceed
    the limit (#2881)
  * Bump k8s.io/kubectl from 0.30.1 to 0.31.0 (#2838)
  * Bump github.com/adrg/xdg from 0.4.0 to 0.5.0 (#2839)
  * fix internal/render/hpa.go merge issue (#2856)
  * Bump github.com/go-errors/errors from 1.4.2 to 1.5.1 (#2840)
  * Bump golang from 1.22-alpine3.20 to 1.23-alpine3.20 (#2837)
  * Add color to hpa line when replicas >= maxpods (#2333)
  * Bump required GO version for build (#2844)
  * Add leading space to Kubernetes context suggestions (#2791)
  * update tview to fix log escaping problem completely (#2830)
  * container logs should be escaped when printed (#2751)
  * Fix: ensure correct ns for helm actions (#2652)
  * should switching ctx before ns (#2750)
  * Loki plugin (#2755)
  * Bump github.com/hashicorp/go-getter from 1.7.4 to 1.7.5 (#2759)
  * enable "jump to owner" for more kinds (#2763)
  * feat: allow plugins block in plugin files (#2770)
  * feat: add duplik8s plugin (#2771)
  * Update helm-purge.yaml (#2787)
  * Update README.md plugin format (#2788)
  * Create kubectl-get-in-shell.yaml (#2789)
  * Bump actions/setup-go from 5.0.1 to 5.0.2 (#2796)
  * add new plugin current-ctx-terminal (#2795)
  * Bump k8s.io/cli-runtime from 0.30.1 to 0.31.0 (#2829)
  * Bump k8s.io/client-go from 0.30.1 to 0.30.3 (#2806)
  * Bump alpine from 3.20.0 to 3.20.2 (#2807)
  * Add a spark-operator plugin (#2821)
  * Adding HolmesGPT plugin (#2822)
  * Bump github.com/docker/docker (#2825)
  * fix: align build image Go version with go.mod (#2812)
  * Bump github.com/docker/docker (#2816)
  * Bump golangci/golangci-lint-action from 6.0.1 to 6.1.0 (#2813)
  * Add comment about Escape keybinding (#2817)
  * proper handle OwnerReference for manually created job (#2772)
  * [#2773] fix freebsd build failure (#2775)
  * install copyright file into correct location (#2780)
  * fix status for completed pods in workload view (#2729)
* Sat Jun 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.5:
  * update deps
  * [Maint] Bump grype rev
  * K9s/release v0.32.5 (#2740)
  * fix view sorting being reset (#2736)
  * use policy/v1 instead of policy/v1beta1 (#2732)
  * Bump alpine from 3.19.1 to 3.20.0 (#2721)
  * fix: jump to namespaceless owner reference (#2718)
  * feat: Add plugins for argo-rollouts (#2711)
  * Bump golangci/golangci-lint-action from 5.1.0 to 6.0.1 (#2702)
  * allow jumping to the owner of the resource (#2700)
  * fix: job color based on failures (#2686) (#2698)
  * Bump actions/setup-go from 5.0.0 to 5.0.1 (#2690)
  * Bump actions/checkout from 4.1.4 to 4.1.5 (#2691)
  * Added cert-manager and openssl plugins. (#2699)
  * Add kanagawa skin (#2676)
  * fix: do not hard-code path to kubectl in jq plugin (#2678)
  * save config when closing k9s with ctrl-c (#2666)
  * Bump github.com/hashicorp/go-getter from 1.7.3 to 1.7.4 (#2682)
  * Bump actions/checkout from 4.1.2 to 4.1.4 (#2683)
  * Bump golangci/golangci-lint-action from 4.0.0 to 5.1.0 (#2684)
  * Bump github.com/docker/docker (#2638)
  * Allow overwriting plugin output with command's stdout (#2644)
  * chore: remove the repetitive word (#2650)
  * Bump helm.sh/helm/v3 from 3.14.3 to 3.14.4 (#2657)
  * checking for nil pointer in merge namespace (#2659)
  * Bump golang.org/x/net from 0.19.0 to 0.23.0 (#2664)
  * Bump github.com/cenkalti/backoff/v4 from 4.2.1 to 4.3.0 (#2647)
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.4:
  * K9s/release v0.32.4 (#2637)
  * fix build snap (#2621)
  * Bump k8s.io/apiextensions-apiserver from 0.29.2 to 0.29.3
    (#2627)
  * Bump helm.sh/helm/v3 from 3.14.2 to 3.14.3 (#2628)
  * Bump k8s.io/kubectl from 0.29.2 to 0.29.3 (#2630)
  * Bump actions/checkout from 4.1.1 to 4.1.2 (#2632)
  * fix: match node label kubernetes.io/role as suffix (#2606)
  * Update brew install steps (#2611)
  * Bump google.golang.org/protobuf from 1.31.0 to 1.33.0 (#2614)
  * fix: pass set retries to transfer command (#2596)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.3:
  * #2584 Transfer of file doesn't detect corruption (with
    feelings!)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.2:
  * #2582 Slowness due to client-side throttling in v0.32.0
    (Maybe??)
  * #2593 Popeye not working in 0.32.X
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.1:
  * #2584 Transfer of file doesn't detect corruption
  * #2579 Default sorting behavior changed to descending sort
    bug
  * #2586 Properly initialize key actions in picker
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.0 (bsc#1220207, CVE-2024-26147):
  * #2569 k9s panics on start if the main config file (config.yml)
    is owned by root
  * #2568 kube context in running k9s is no longer sticky, during
    kubectx context switch
  * #2560 Namespace/Settings keeps resetting
  * #2557 [Feature]: Sort CRDs by their group
  * #1462 k9s running very slowly when opening namespace with 13k
    pods (maybe??)
  * #2564 Add everforest skins
  * #2558 feat: sort by role in node list view
  * #2554 Added context to the debug command for debug-container
    plugin
  * #2554 Correctly respect the KUBECACHEDIR env var
  * #2546 Use configured log fgColor to print log markers
* Mon Feb 19 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.9:
  * K9s/release v0.31.9 (#2543)
  * Add moon and dawn variants (#2537)
  * fix: issue 2175 - fallback to env names when cannot get
    username from user.Current() (#2505)
  * fix the --write flag (#2531)
  * Bump golangci/golangci-lint-action from 3.7.0 to 4.0.0 (#2534)
  * Bump helm.sh/helm/v3 from 3.14.0 to 3.14.1 (#2541)
  * feat: allow override of plugins & hotkeys shortcuts (#2510)
  * Add liveMigration example to plugins (#2522)
* Wed Feb  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.8:
  * Resolved Issues
  - #2527 Multiple k9s panels open in parallel for the same
    cluster breaks config.yaml
  - #2520 pods with init container with restartPolicy: Always
    stay in Init status
  - #2501 Cannot add plugins to helm scope bug
  - #2492 API Resources "carry over" between contexts, causing
    errors if they share shortnames
  - #1158 Removing a helm release incorrectly determines the
    namespace of resources
  - #1033 Helm delete deletes only the helm entry but not the
    deployment
* Thu Jan 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.7:
  * Resolved Issues
  - [#2488](https://github.com/derailed/k9s/issues/2488)
    linux_amd64 "--kubeconfig" not working on v0.31.6
* Thu Jan 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.6:
  * K9s/release v0.31.6 (#2487)
  * Adding system arch to nodes view (#2480)
  * shell autocomplete for k8s flags (#2477)
  * Bump k8s.io/klog/v2 from 2.110.1 to 2.120.0 (#2474)
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.5:
  * Resolved Issues
  - #2466 Panic: index out of range [0] with length 0
  - #2465 v0.31.4 - panic; no client connection detected - with
    feelings!!
* Mon Jan 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.4:
  * Resolved Issues
  - #2463 v0.31.3 (Linux_amd64) gives runtime error on startup
* Wed Jan 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.3:
  * Resolved Issues
  - #2459 No permission to see deployments/statefulsets even
    though I have them
  - #2458 panic on run without current context
  - #2454 Invoking K9s ends in panic question
  - #2435 "yaml: line 15: could not find expected ':'" error bug
    question (May be??)
* Tue Jan  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.2:
  * Resolved Issues
  - #2449 [Bug]: views.yaml columns not respected on startup
  - #2448 Missing '.thresholds' in config.yaml result in
    'assignment to entry in nil map'
  - #2446 Context Switch unreliable/not working
* Tue Jan  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.1:
  * With this release, k9s may not start correctly if the
    config.yaml configurations are incorrect!
    Configuration changes:
  - DRY fullScreenLogs -> fullScreens (k9s root config.yaml)
  - Views Configuration.
    To match other configurations the root is now views: vs
    k9s: views:
  * Serenity Now!
    You can now opt in/out of the reactive ui feature. This feature
    enable users to make change to some configurations and see
    changes reflected live in the ui. This feature is now disabled
    by default and one must opt-in to enable via k9s.UI.reactive
    Reactive UI provides for monitoring various config files on
    disk and update the UI when changes to those files occur. This
    is handy while tuning skins, plugins, aliases, hotkeys and
    benchmarks parameters.
  * Resolved Issues
  - #2434 readOnly: true in config.yaml doesnt get overriden by
    readOnly: false in cluster config
  - #2430 Referencing a namespace with the name of an alias
    inside an alias causes infinite loop
  - #2428 Boom!! runtime error: invalid memory address or nil
    pointer dereference - v0.30.8
  - #2421 k9s/config.yaml configuration file is overwritten on
    launch
* Tue Jan  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.31.0:
  * [Bug] Fix #2428
  * K9s/release v0.31.0 (#2440)
  * Bump github.com/anchore/grype from 0.73.5 to 0.74.0 (#2439)
  * Bump github.com/cloudflare/circl from 1.3.3 to 1.3.7 (#2438)
  * switch contexts only when needed (#2433)
  * README update (#2429)
  * chore: rebasing off main and resolving conflicts (#2314)
  * fix typo (#2419)
  * Update carvel plugin kick to shift K (#2426)
  * supports referencing envs in hotkeys (#2420)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.8:
  * K9s/release v0.30.8 (#2427)
  * fix the check for whether the cluster supports metrics (#2424)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.7:
  * K9s/release v0.30.7 (#2416)
  * Use dash as a standard word separator in skin names (#2411)
  * Add support for resource recommendations using Robusta KRR
    (#2399)
  * add boundary check for args parser (#2415)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.6:
  * K9s/release v0.30.6 (#2403)
  * add kubectl-blame plugin (#2338)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.5:
  * K9s/release v0.30.5 (#2397)
  * fix: create user tmp directory before the app one (#2395)
  * feat: allow to customize logs dir through environment variable
    (#2396)
  * Add plugin to remove finalizers (#2359)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.4:
  * K9s/release v0.30.4 (#2392)
  * case sensitive for specific command args and flags (#2390)
  * v0.30.3 version update (#2383)
  * fix #2382 (#2386)
  * Bump helm.sh/helm/v3 from 3.13.2 to 3.13.3 (#2384)
  * Bump github.com/anchore/grype from 0.73.4 to 0.73.5 (#2385)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.3:
  * K9s/release v0.30.3 (#2381)
  * Update build v0.30.2 (#2380)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.2:
  * K9s/release v0.30.2 (#2376)
  * get node filtering params from matching context values (#2375)
  * fix cmdline flags not working (#2373)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.1:
  * K9s/release v0.30.1 (#2369)
  * adding cancelable launch prompts to NodeShell (#2360)
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.30.0:
  * K9s/rel v0.30.0 (#2361)
  * Added ln check for snap (#2357)
  * Bump helm.sh/helm/v3 from 3.13.2 to 3.13.3 (#2353)
  * Bump golang.org/x/crypto from 0.16.0 to 0.17.0 (#2355)
  * Bump github.com/containerd/containerd from 1.7.8 to 1.7.11
    (#2358)
  * adding value, yaml and describe views to helm-history (#2341)
  * #1873 add symlink into snap (#2350)
  * fix(misc plugins): split up multiline commands, use less -K
    everywhere (#2348)
  * Bump alpine from 3.18.5 to 3.19.0 (#2337)
  * add pkgx to installation section (#2340)
  * Bump actions/setup-go from 4.1.0 to 5.0.0 (#2339)
  * passing on the correct suggestion parameters (#2343)
  * adding a default value for the AGE field (#2320)
  * fix fuzzy matching not working properly (#2321)
  * Bump alpine from 3.18.4 to 3.18.5 (#2325)
  * update container revs
* Thu Dec  7 2023 kastl@b1-systems.de
- Update to version 0.29.1:
  * [HotFix] Fix issues #2330 #2329 #2327
* Thu Dec  7 2023 kastl@b1-systems.de
- Update to version 0.29.0:
  * K9s Release v0.29.0 (#2326)
  * check if the service provides selectors (#2322)
  * proper handling of help commands (fixes #2154) (#2319)
  * fix namespace suggestion error on context switch (#2315)
  * Bump github.com/derailed/tview from 0.8.1 to 0.8.2 (#2316)
  * Bump k8s.io/kubectl from 0.28.3 to 0.28.4 (#2318)
  * add suggestions for context and resources on the command bar
    (#2285)
  * Allow both .yaml and .yml yaml config files (#2284)
  * chore: use k8s.io/kubernetes as a dependency is unsupported and
    not recommended (#2310)
  * should not be clear screen when exeuting plugin (#2313)
  * feat: add imagePullSecrets and imagePullPolicy configuration
    for shellpod (#2301)
  * Bump helm.sh/helm/v3 from 3.13.1 to 3.13.2 (#2293)
  * Bump k8s.io/cli-runtime from 0.28.3 to 0.28.4 (#2306)
  * Bump k8s.io/client-go from 0.28.3 to 0.28.4 (#2305)
  * Clean up items... (#2303)
  * Bump k8s.io/klog/v2 from 2.100.1 to 2.110.1 (#2294)
  * Bump golang.org/x/text from 0.13.0 to 0.14.0 (#2295)
  * Bump sigs.k8s.io/yaml from 1.3.0 to 1.4.0 (#2296)
  * add flux plugin image reconciliation commands (#1445)
  * added flux suspended resources retrieval plugin (#1584)
  * Provide white blur so images work in dark modes (#1597)
  * Add context to get-all (#1701)
  * fix brew command in the readme (#2012)
  * Add support for using custom kubeconfig with log_full plugin
    (#2014)
  * feat: allow for multiple plugin files in
    $XDG_DATA_DIRS/k9s/plugins (#2029)
  * Clean up issues introduced by #2125 (#2289)
  * Pod view resembles more the output of kubectl get pods -o wide
    (#2125)
  * Update README.md with snap install (#2262)
  * Add snapcraft config (#2123)
  * storageclasses view keeps the same output as kubectl get sc
    (#2132)
  * Fix merge issues with PR #2168 (#2288)
  * Add colour config for container picker (#2140)
  * Add env var to disable node pod counts (#2168)
  * Use current k9s NS if new context has no default NS (#2197)
  * Bump actions/setup-go from 4.0.1 to 4.1.0 (#2200)
  * fix: trigger a single log refresh after changing 'since'
    (#2202)
  * Add crossplane plugin (#2204)
  * fix(#1359): add option to keep missing clusters in config
    (#2213)
* Mon Nov 13 2023 kastl@b1-systems.de
- Update to version 0.28.2:
  * K9s release v0.28.2
  * restore delete shortcut
* Mon Nov 13 2023 kastl@b1-systems.de
- Update to version 0.28.1:
  * try to get the os name form the pod assigned node (#2282)
  * Add sanitize command (#2286)
  * Delete port forwards when pods get deleted or killed (#2247)
  * Add prompt border color customization (#2234)
  * check if the Node already cordoned when executing Drain (#2275)
  * README.md: fix typo in netshoot URL (#2278)
  * chore: replace `github.com/ghodss/yaml` with `sigs.k8s.io/yaml`
    (#2280)
  * feat: add autoRefresh config field (#2256) (#2257)
  * return the correct benchamrk path (#2272)
  * K9s/rel v0.28.0 (#2274)
  * chore(deps): bump github.com/fatih/color from 1.15.0 to 1.16.0
    (#2269)
  * chore(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0
    (#2270)
  * chore(deps): bump k8s.io/klog/v2 from 2.100.1 to 2.110.1
    (#2271)
* Tue Nov  7 2023 kastl@b1-systems.de
- BuildRequire go1.21
- Update to version 0.28.0:
  * release v0.28.0
  * Introduce File transfer command
  * Various fixes and clean up
  * check for plausible overflow when seting up env
  * fix manual sorting not working when sortColumn is configured
    (#2253)
  * chore(deps): bump github.com/rs/zerolog from 1.29.1 to 1.31.0
    (#2241)
  * chore(deps): bump github.com/docker/docker (#2266)
  * fix fsnotify not fully working (#2258)
  * chore(deps): bump github.com/fsnotify/fsnotify from 1.6.0 to
    1.7.0 (#2259)
  * chore(deps): bump actions/checkout from 4.1.0 to 4.1.1 (#2260)
  * chore(deps): bump google.golang.org/grpc from 1.54.0 to 1.56.3
    (#2263)
  * chore(deps): bump k8s.io/metrics from 0.28.2 to 0.28.3 (#2254)
  * chore(deps): bump helm.sh/helm/v3 from 3.13.0 to 3.13.1 (#2250)
  * consider units when sorting capacity (#2252)
  * fix: honor defaults from drain dialog in request (#2239)
  * chore(deps): bump golang.org/x/text from 0.12.0 to 0.13.0
    (#2242)
  * chore(deps): bump golang.org/x/net from 0.13.0 to 0.17.0
    (#2245)
  * fix(typo): pdb header typo (#2243)
  * docs: add plugin.yml JSON schema (#2235)
  * fix(log): clear bold log format after timestamp (#2229)
  * Bump actions/checkout from 3.5.2 to 4.1.0 (#2232)
  * Bump helm.sh/helm/v3 from 3.12.0 to 3.13.0 (#2236)
  * Bump alpine from 3.18.3 to 3.18.4 (#2237)
  * Bump k8s.io/metrics from 0.27.1 to 0.27.4 (#2172)
  * chore(skins): add solarized-16 (dark/light) (#2176)
  * Bump golang.org/x/text from 0.11.0 to 0.12.0 (#2191)
  * Bump alpine from 3.18.2 to 3.18.3 (#2192)
  * Update flux.yml with shortcuts for helm repo and oci repos
    (#2141)
  * feat: Added support for arm in dockerfile (#2180)
  * feat(alias): add `qa` for quit (#2188)
  * Focus command bar if active on startup (#2179)
  * Bump golang.org/x/text from 0.9.0 to 0.11.0 (#2182)
  * Bump alpine from 3.18.0 to 3.18.2 (#2142)
  * Bump k8s.io/cli-runtime from 0.27.2 to 0.27.4 (#2174)
  * Show the default container as the first entry (#2158)
  * Changed checksums extension to checksums.sha256 (#2153)
  * Only apply keyConv to mnemonic in menus (#2161)
  * Add namespace for rolebinding on a clusterrole (#2170)
  * feat: plugin for adding an ephemeral debug container (#2147)
  * chore: pkg imported more than once (#2151)
  * Remove unsupported key binding on users view (#2134)
  * Correctly display the numbers in the Ready column of the pods
    view (#2137)
  * Bump github.com/spf13/cobra from 1.6.1 to 1.7.0 (#2110)
  * Bump helm.sh/helm/v3 from 3.11.1 to 3.12.0 (#2116)
  * Fix for styles (#2112)
  * Add instruction how to install k9s through winget (#2117)
  * fix: add correct flags when deleting resources from Dir (#2124)
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.3 (#2111)
  * Bump github.com/fvbommel/sortorder from 1.0.2 to 1.1.0 (#2080)
  * Bump github.com/cenkalti/backoff/v4 from 4.2.0 to 4.2.1 (#2081)
  * Bump github.com/docker/distribution (#2088)
  * Bump k8s.io/cli-runtime from 0.26.1 to 0.27.2 (#2102)
  * Bump alpine from 3.17.3 to 3.18.0 (#2093)
  * Add get-all plugin specific for namespace view (#2091)
  * Bump k8s.io/client-go from 0.27.0 to 0.27.2 (#2101)
  * Update carvel.yml to include contexts (#2103)
  * Fix the wrong/redundant icon in the prompt bar (#2105)
  * fix: (config) only respect the --command flag once (#2096)
  * Bump actions/setup-go from 4.0.0 to 4.0.1 (#2092)
  * Bump golang from 1.20.3-alpine3.16 to 1.20.4-alpine3.16 (#2078)
  * Fix typo introduced in #2045 (#2082)
* Mon May  8 2023 kastl@b1-systems.de
- Update to version 0.27.4:
  * Rel v0.27.4 (#2075)
  * feat: allow customization of log indicator toggles closes #2024
    (#2041)
  * Create narsingh.yml (#2067)
  * fix: (views) use saved context view when switching (#2045)
  * Unify all go version to 1.20 (#2069)
  * Bump github.com/rs/zerolog from 1.29.0 to 1.29.1 (#2060)
  * Bump helm.sh/helm/v3 from 3.11.1 to 3.11.3 (#2059)
  * Fix for missing Job annotations created from CronJob (#2073)
  * Roles are rendered using same colorer function from skin
    (#2027)
  * Bump github.com/fatih/color from 1.14.1 to 1.15.0 (#2023)
  * Updated monokai skin with help styles, and more monokai
    appropriate colors (#2030)
  * Bump alpine from 3.17.2 to 3.17.3 (#2040)
  * Bump github.com/docker/docker (#2044)
  * Bump actions/checkout from 3.3.0 to 3.5.2 (#2058)
  * Bump golang from 1.20.2-alpine3.16 to 1.20.3-alpine3.16 (#2049)
  * Update setup-go action, with caching (#2054)
  * Convert command to lowercase in the command palette (#1432)
  * Allowing a few hard coded colors to be configurable (#1405)
  * fix: multiple matches in a single line. (#1876)
  * generated binary zip for windows (#1972)
  * feat: add support for renaming contexts. (#2006)
  * Fix accessing nil map (#1996)
  * Sort by view default only if sort not currently set (#1962)
  * fix: fix outdated stern links (#1990)
  * Update k8s matrix (#1979)
  * Bump github.com/containerd/containerd from 1.6.15 to 1.6.18
    (#1981)
  * Bump github.com/derailed/popeye from 0.11.0 to 0.11.1 (#1986)
  * adding instruction to install in FreeBSD via pkg (#1991)
  * Bump k8s.io/metrics from 0.26.1 to 0.26.2 (#1998)
  * added full logs viewing (#2002)
  * Bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#1993)
  * Bump k8s.io/client-go from 0.26.1 to 0.26.2 (#1999)
  * Bump golang.org/x/net from 0.5.0 to 0.7.0 (#2000)
  * Bump golang from 1.20.0-alpine3.16 to 1.20.2-alpine3.16 (#2008)
  * Fix #2007: Remove debug command (#2011)
  * Bump alpine from 3.17.1 to 3.17.2 (#1974)
  * Bump golang.org/x/text from 0.6.0 to 0.7.0 (#1976)
  * Bump github.com/derailed/popeye from 0.10.1 to 0.11.0 (#1975)
  * Add missing help menu to one_dark skin (#1973)
* Sun Feb 12 2023 kastl@b1-systems.de
- Update to version 0.27.3 (bsc#1208087, CVE-2023-25165):
  * Release v0.27.3 (#1970)
  * Add sort by pod count on node view (#1961)
  * fix: Show meaningful error message when kubectl exec fails (#1966)
  * set default sinceSeconds to 300 (#1965)
  * Match ${XXX} environment variables (#1896)
  * Bump github.com/cenkalti/backoff/v4 from 4.1.3 to 4.2.0 (#1957)
  * Bump k8s.io/klog/v2 from 2.80.1 to 2.90.0 (#1958)
  * Bump golang from 1.19.5-alpine3.16 to 1.20.0-alpine3.16 (#1956)
  * Bump github.com/fatih/color from 1.13.0 to 1.14.1 (#1959)
  * Added Nightfox theme (#1960)
  * fix: Add missing help menu to gruvbox-dark skin (#1969)
  * Bump helm.sh/helm/v3 from 3.11.0 to 3.11.1 (#1963)
  * update docs
  * fix: acessing clusters with private dns (#1903)
  * Bump actions/setup-go from 3.3.1 to 3.5.0 (#1899)
  * Bump helm.sh/helm/v3 from 3.10.1 to 3.11.0 (#1928)
  * Bump github.com/rs/zerolog from 1.28.0 to 1.29.0 (#1942)
- BuildRequire go1.19
* Wed Feb  1 2023 kastl@b1-systems.de
- Update to version 0.27.2:
  * fix brew installer
  * bring out the duds
* Tue Jan 31 2023 kastl@b1-systems.de
- Update to version 0.27.1:
  * release v0.27.1 (#1945)
  Resolved Issues
  * [Issue #1943](https://github.com/derailed/k9s/issues/1943) k9s display is broken after switching to v0.27.0
  * [Issue #1935](https://github.com/derailed/k9s/issues/1935) Active namespace is dropped after accessing forbidden resources
  * [Issue #1913](https://github.com/derailed/k9s/issues/1913) Exit edit mode deadlock
  * [Issue #1895](https://github.com/derailed/k9s/issues/1895) AWS workspace. K9s fails on startup with unknown userid error
  * [Issue #1842](https://github.com/derailed/k9s/issues/1842) Strange one - brew installed k9s
* Fri Jan 27 2023 kastl@b1-systems.de
- Update to version 0.27.0:
  * K9s/rel v0.27.0 (#1932)
  * Bump alpine from 3.16.2 to 3.17.1 (#1907)
  * Replace x86_64 to amd64 build (#1910)
  * Bump actions/checkout from 3.1.0 to 3.3.0 (#1908)
  * Bump golang from 1.19.2-alpine3.16 to 1.19.5-alpine3.16 (#1915)
  * Use default terminal colors for better readability (#1290) (#1837)
  * Add labels configuration to Shell node pod (#1847)
  * Set build date on macos (#1849)
  * Update ScanSA calls to account for blank service accounts (#1871)
  * Add k8s client compatibility matrix (#1872)
  * bugfix for port forward custom containers not showing #1844 (#1877)
  * feat: add noLatestRevCheck config option (#1874)
  * Add policy view to serviceAccounts (#1840)
  * Add VIM-like quit force option. (#1859)
  * Fix order of arguments for `CanI` function call (#1866)
  * Update README.md (#1696)
  * Bump all references of github.com/cenkalti/backoff to v4 (#1821)
  * Plugin support for carvel kapp CR (#1830)
  * flux.yml plugin now displays stderr messages (#1829)
  * Bump actions/setup-go from 3.1.0 to 3.3.1 (#1817)
* Tue Oct 18 2022 kastl@b1-systems.de
- Update to version 0.26.7:
  * K9s/rel v0.26.7 (#1816)
  * Bump k8s.io/klog/v2 from 2.70.1 to 2.80.1 (#1779)
  * Bump github.com/rs/zerolog from 1.27.0 to 1.28.0 (#1780)
  * Bump golang from 1.19.1-alpine3.16 to 1.19.2-alpine3.16 (#1796)
  * Bump actions/checkout from 2 to 3.1.0 (#1795)
  * Bump github.com/mattn/go-runewidth from 0.0.13 to 0.0.14 (#1813)
  * Bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#1814)
  * Allow multiple port forwards for a single Pod (#1804)
  * Bump k8s.io/kubectl from 0.25.1 to 0.25.3 (#1809)
  * Bump golang.org/x/text from 0.3.7 to 0.4.0 (#1812)
  * Bump github.com/fsnotify/fsnotify from 1.5.4 to 1.6.0 (#1810)
  * Bump k8s.io/cli-runtime from 0.25.1 to 0.25.3 (#1811)
  * use go install (#1797)
  * Bump k8s.io/client-go from 0.25.1 to 0.25.3 (#1806)
  * Bump k8s.io/metrics from 0.25.1 to 0.25.3 (#1807)
  * Bump k8s.io/apimachinery from 0.25.1 to 0.25.3 (#1808)
  * Update CronJob version to v1 (#1793)
* Tue Sep 27 2022 kastl@b1-systems.de
- Update to version 0.26.6:
  * K9s/rel v0.26.6 (#1784)
  * fix #1773
  * Fix directory path when viewing ScreenDump (#1777)
  * docs: update homebrew installation note (#1772)
  * Log toggles: add a space after "On" in logs view (#1775)
  * Add a closing tag when showing timestamp in log view (#1776)
* Sun Sep 25 2022 kastl@b1-systems.de
- Update to version 0.26.5:
  * release v0.26.5 (#1771)
* Sun Sep 25 2022 kastl@b1-systems.de
- Update to version 0.26.4:
  * clean up test
  * K9s/rel v0.26.4 (#1767)
  * Replace clipboard package (#868) (#1721)
  * List all helm releases (#1755)
  * Fix GracePeriodSeconds (#1739)
  * Plugin for opening a root shell to k3d containter (#1709)
  * Fix  Get CustomResourceDefinition(#1711) (#1722)
  * Fix flux plugin to properly handle trace (#1753)
  * README : correct (auto-)port-forwards annotations (#1744)
  * Fix typo in cronjob (#1759)
  * Bump golang from 1.19.0-alpine3.16 to 1.19.1-alpine3.16 (#1754)
  * fix redundant type conversion code (#1725)
  * update tag
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.3:
  * hotfix: windoze
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.2:
  * K9s/rel v0.26.2 (#1691)
* Wed Sep  7 2022 kastl@b1-systems.de
- Update to version 0.26.1:
  * K9s/rel v0.26.1 (#1685)
  * Fix persistentvolumes not showing terminating status (#1682)
  * Show UsedBy for PriorityClasses (#1666)
  * feat: allow disable CTRL-C behavior (#1672)
  * Fix PF delete with no container (#1668)
* Mon Jul 18 2022 kastl@b1-systems.de
- Update to version 0.26.0:
  * cleaning up deprecation
  * K9s/rel v0.26.0 (#1660)
  * Fix PF and RS colors (#1656)
  * Fix #1636: can't switch context with --kubeconfig flag (#1638)
* Fri Jul  1 2022 kastl@b1-systems.de
- Update to version 0.25.21:
  * K9s rel v0.25.21 (#1635)
  * Fix delete dialog dropdown styling (#1632)
  * Fix TestToAge (#1627)
  * Fix reference to base image in Dockerfile (#1629)
  * [FIX] chg makefile version (#1624)
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.25.20:
  * K9s release v0.25.20 (#1621)
  * Issue #1620 popeye view shows duplicate pdb
  * Issue #1616 Age in nodes view are n/a
* Tue Jun 28 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go1.18, as upstream says in go.mod
* Tue Jun 28 2022 kastl@b1-systems.de
- Update to version 0.25.19:
  * update deps
  * K9s release v0.25.19 (#1610)
  * Fix typo in FastForwards annotation name (#1600)
  * Capitalise true/false when checking suspension (#1601)
  * Allow all deletion propagation policies (#1553)
  * fix: correct typo (#1566)
  * Add Helm values support (#1518)
  * Add locking favorite namespaces (#1449) (#1519)
  * plugin to allow default chart values retrieval (#1539)
  * fix view details secret fullscreen padding to 0 (#1493)
  * Fix the flux plugin to use the context of the currently running instance (#1366)
  * Fix Typo (#1422)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.18:
  * Issue #1402 Sort functionality does not work properly on v0.25.16. With Feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.17:
  * Issue #1402 Sort functionality does not work properly on v0.25.16
  * Issue #1401 Nothin selected when last item deleted
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.16:
  * Issue #1398 Pod logs containing brackets not in k9s logs output
  * Issue #1397 Regression: k9s no longer starts in current context namespace since v0.25.12
  * Issue #1358 Namespaces list is empty
  * Issue #956 Feature request : Default column sort (by resource view)
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.15:
  * Issue #1384 Leaving Logs View Causes Crash: "panic: send on closed channel" - with feelings!
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.14:
  * Issue #1384 Leaving Logs View Causes Crash: "panic: send on closed channel"
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.13:
  * Issue #1382 Watcher failed for screendumps
  * Issue #1381 --request-timeout affects logs streaming
  * Issue #1380 :pulse returning error: expecting a TableRow but got *v1.Table
  * Issue #1376 Events are not sorted correctly by dates - with feelings...
  * Issue #1291 K9s do not show any error when is unable to get logs, just do not show anything.
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.12:
  * Issue #1378 Regression: Namespace filters are no longer applied on startup
  * Issue #1376 Events not sorted correctly by dates
  * Issue #1375 Unable to show port forwards
  * Issue #1374 --all-namespaces does not work v0.25.10
  * Issue #1373 change namespace not possible
* Wed Jan  5 2022 kastl@b1-systems.de
- Update to version 0.25.10:
  * update rev
  * must get moore sleep!
  * k9s: release v0.25.9 (#1364)
  * Add customizable dump directory property (#1321)
  * Add flux trace shortcut to flux plugin (#1356)
  * Add rose-pine skin (#1363)
* Sun Dec  5 2021 dmueller@suse.com
- Update to version 0.25.8:
  * release v0.25.8 (#1354)
  * add logFile flag to change the default log file path (#1336)
  * Support colors on Windows (#1312)
* Sun Nov 28 2021 Lingchao Xin <douglarek@gmail.com>
- Update to version 0.25.7:
  - Bug fixes
  * Issue #1341 Colored container logs are not displayed correctly
  See more: https://github.com/derailed/k9s/releases/tag/v0.25.7
* Fri Nov 26 2021 douglarek@gmail.com
- Update to version 0.25.6:
  - Bug fixes
  * Log level not showing in k9s
  * Namespace filter automatically applied after viewing a deployment
  See more: https://github.com/derailed/k9s/releases/tag/v0.25.6
* Fri Aug 13 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.15:
  - Breaking changes
  * K9s home directory is now configurable via XDG
  - Bug fixes
  * Popeye run instructions
  * K9s does not remember last view when switching contexts
  * Cannot list roles
* Fri Jul 23 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.14:
  * Bug fixes
- Drop Makefile.patch as new build variables were added to the Makefile
* Tue May 25 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.10:
  * Bug fixes
- Update Makefile.patch to version 0.24.10
* Fri May  7 2021 dmueller@suse.com
- Update to version 0.24.9:
  * fix shell issue + bugz
  * Dynamically load style for help from skin (#1113)
  * Solarized light skin (#1114)
  * Update docs
  * add rel notes
  * when k9s --insecure-skip-tls-verify is set, kubectl would set the same (#1101)
  * Add Nord skin (#1103)
  * wins palette
  * Spelling (#1089)
  * Allow to override build date with SOURCE_DATE_EPOCH (#1099)
  * Create axual.yml (#934)
  * Add gruvbox skins (#1088)
* Sat Apr 10 2021 dmueller@suse.com
- Update to version 0.24.7:
  * cleaning up
  * bump rev
  * maintenance #1067 #1061 #1060
  * rev up
  * merge prs + dep updates
  * ISSUE-957 - Add a simple pause button to stop auto-refresh on ConfigMap and Secrets (#1062)
  * bugs #1063 #1061 #1059 #177
  * Add release tag (#1058)
  * fix #1056 #1024
  * fix po feature col + lockouts?
* Mon Mar 29 2021 alexandre.vicenzi@suse.com
- Update to version 0.24.6:
  * rev up
  * merge prs + dep updates
  * ISSUE-957 - Add a simple pause button to stop auto-refresh on ConfigMap and Secrets (#1062)
  * bugs #1063 #1061 #1059 #177
  * Add release tag (#1058)
  * fix #1056 #1024
  * fix po feature col + lockouts?
  * fix #1024
  * update deps and image
- Rename Makefile.diff to Makefile.patch
* Fri Jan  8 2021 rbrown@suse.com
- Update to version 0.24.2:
  * add rel notes
  * cleanup + rel notes
  * fix typo and clean up prs
  * Add OneDark color theme.
  * handling non json lines as raw with red color
  * Disable filtering on the Help screen
  * Handle Empty Port List in PortForward View
* Sat Dec  5 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.24.1 (bsc#1179668):
  * Add Monokai skin
  * Print resources in pod view
  * Slow down reconnection rate on auth failures
  * Logs page for any pod/container shows Waiting for logs...
  * Support sort by pending status
  * Wrong highlight position when filtering logs
  * Disable read only config via command line flag
  * Ability to call out a separate program to parse/filter logs
  * Full screen mode or remove borders in YAML view for easy copy/paste
  * Refresh for describe & yaml view
  * View logs quickly scrolls through entire logs when initially loading
  * Support an inverse operator on filtered search
  * Log file spammed despite K9s not running
  * Events view
  * Dozens of bug fixes
- Makefile.diff: refresh
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.21.7:
  - see https://github.com/derailed/k9s/releases
* Mon Mar 30 2020 Michal Vyskocil <mvyskocil@opensuse.org>
- Update to version 0.18.1
  - Many bug fixes
  - Many new features (auto suggestions, revisited logs, k9 plugins)
  - see https://github.com/derailed/k9s/releases/
* Tue Feb 18 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.15.2
  - Many bug fixes
  - Many new features
* Mon Jan 20 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.13.0
  - Add Dracula Skin
  - Add XRay Vision
  - Bug fixes
- Update vendor.tar.gz
* Mon Jan 13 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.12.0
  - Performance fixes
  - Searchable Logs
  - APIServer Dud
  - FullScreen Logs
* Tue Jan  7 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 0.11.2
  - Many bug fixes
  - Prelimary support for Helm 3 charts
  - Major rework of the core
  - Custom skins per cluster
* Thu Nov  7 2019 kukuk@suse.de
- Initial version
